# Generated by Django 4.2 on 2023-05-10 11:09

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("permissions", "0004_create_anonymous_user"),
        ("flow", "0012_alter_relation_category"),
    ]

    operations = [
        migrations.AlterField(
            model_name="annotationpreset",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
        migrations.AlterField(
            model_name="collection",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
        migrations.AlterField(
            model_name="data",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
        migrations.AlterField(
            model_name="descriptorschema",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
        migrations.AlterField(
            model_name="entity",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
        migrations.AlterField(
            model_name="process",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
        migrations.AlterField(
            model_name="relation",
            name="permission_group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to="permissions.permissiongroup",
            ),
        ),
    ]
